#ifndef ROFI_DIALOGS_DIALOGS_H
#define ROFI_DIALOGS_DIALOGS_H

/**
 * @defgroup MODES Modes
 */
/**
 * List of available dialogs.
 */

#include "dialogs/run.h"
#include "dialogs/ssh.h"
#include "dialogs/drun.h"
#include "dialogs/dmenu.h"
#include "dialogs/script.h"
#include "dialogs/window.h"
#include "dialogs/combi.h"
#include "dialogs/help-keys.h"
#endif // ROFI_DIALOGS_DIALOGS_H
